@@ -10,6 +10,7 @@ and to include the docstring of the ``'__call__'`` attribute.
 **Disclaimer**
 
 Copyright 2016-2019, Philipp S. Sommer
+
 Copyright 2020-2021, Helmholtz-Zentrum Hereon
 
 Licensed under the Apache License, Version 2.0 (the "License");
@@ -38,7 +39,7 @@ __email__ = "philipp.sommer@hereon.de"
 
 __status__ = "Production"
 
-__version__ = '0.2.5'
+__version__ = '0.2.7'
 
 from itertools import chain
 
@@ -181,6 +182,10 @@ class AutosummaryDocumenter(object):
         self.real_modname = None or self.get_real_modname()
 
         # try to also get a source code analyzer for attribute docs
+        if sphinx_version < [4, 0]:
+            record_dependencies = self.directive.filename_set
+        else:
+            record_dependencies = self.directive.record_dependencies
         try:
             self.analyzer = ModuleAnalyzer.for_module(self.real_modname)
             # parse right now, to get PycodeErrors on parsing (results will
@@ -192,9 +197,9 @@ class AutosummaryDocumenter(object):
             self.analyzer = None
             # at least add the module.__file__ as a dependency
             if hasattr(self.module, '__file__') and self.module.__file__:
-                self.directive.filename_set.add(self.module.__file__)
+                record_dependencies.add(self.module.__file__)
         else:
-            self.directive.filename_set.add(self.analyzer.srcname)
+            record_dependencies.add(self.analyzer.srcname)
 
         self.env.temp_data['autodoc:module'] = self.modname
         if self.objpath:
@@ -487,9 +492,8 @@ class CallableAttributeDocumenter(AttributeDocumenter):
                     docstring = force_decode(docstring, encoding)
                 doc.append(prepare_docstring(docstring, ignore))
         else:
-            ignore = _get_arg("ignore", 0, 1, *args, **kwargs)
             for docstring in docstrings:
-                doc.append(prepare_docstring(docstring, ignore))
+                doc.append(prepare_docstring(docstring))
 
         return doc
 
